@@ -1,7 +1,7 @@
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 2000-2016. All Rights Reserved.
+%% Copyright Ericsson AB 2000-2022. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -56,7 +56,7 @@
 %% Open or create a database table. In the mnesia/dets case, 
 %% where the table is stored on disc, it could be of interest
 %% to clear the table. This is controlled by the Action parameter.
-%% An empty node list ([]), is traslated into a list containing
+%% An empty node list ([]), is translated into a list containing
 %% only the own node.
 %% ---------------------------------------------------------------
 open({mnesia,Nodes,clear}, Name, RecName, Attr, Type) when is_list(Nodes) ->
@@ -534,16 +534,16 @@ dets_backup(close, _Cont, _Name, B) ->
     ok;
 dets_backup(read, Cont1, Name, B) ->
     case dets:bchunk(Name, Cont1) of
+	{error, _} = ERROR ->
+	    ERROR;
+	'$end_of_table' ->
+	    dets:close(B),
+	    end_of_input;
 	{Cont2, Data} ->
 	    F = fun(Arg) ->
 			dets_backup(Arg, Cont2, Name, B)
 		end,
-	    {Data, F};
-	'$end_of_table' ->
-	    dets:close(B),
-	    end_of_input;
-	Error ->
-	    Error
+	    {Data, F}
     end.
 
 
